@@ -36,7 +36,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDomain", params)
+            headers = request.headers
+            body = self.call("CreateDomain", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDomainResponse()
@@ -64,7 +65,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDomainAlias", params)
+            headers = request.headers
+            body = self.call("CreateDomainAlias", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDomainAliasResponse()
@@ -92,7 +94,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDomainBatch", params)
+            headers = request.headers
+            body = self.call("CreateDomainBatch", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDomainBatchResponse()
@@ -120,7 +123,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDomainGroup", params)
+            headers = request.headers
+            body = self.call("CreateDomainGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDomainGroupResponse()
@@ -148,7 +152,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateRecord", params)
+            headers = request.headers
+            body = self.call("CreateRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateRecordResponse()
@@ -176,7 +181,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateRecordBatch", params)
+            headers = request.headers
+            body = self.call("CreateRecordBatch", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateRecordBatchResponse()
@@ -204,7 +210,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteDomain", params)
+            headers = request.headers
+            body = self.call("DeleteDomain", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteDomainResponse()
@@ -232,7 +239,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteDomainAlias", params)
+            headers = request.headers
+            body = self.call("DeleteDomainAlias", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteDomainAliasResponse()
@@ -260,7 +268,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteRecord", params)
+            headers = request.headers
+            body = self.call("DeleteRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteRecordResponse()
@@ -288,7 +297,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteShareDomain", params)
+            headers = request.headers
+            body = self.call("DeleteShareDomain", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteShareDomainResponse()
@@ -316,7 +326,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBatchTask", params)
+            headers = request.headers
+            body = self.call("DescribeBatchTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBatchTaskResponse()
@@ -344,7 +355,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDomain", params)
+            headers = request.headers
+            body = self.call("DescribeDomain", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDomainResponse()
@@ -362,6 +374,64 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDomainAliasList(self, request):
+        """获取域名别名列表
+
+        :param request: Request instance for DescribeDomainAliasList.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeDomainAliasListRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.DescribeDomainAliasListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDomainAliasList", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDomainAliasListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeDomainAnalytics(self, request):
+        """统计各个域名的解析量，帮助您了解流量情况、时间段分布。支持查看近 3 个月内的统计情况
+
+        :param request: Request instance for DescribeDomainAnalytics.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeDomainAnalyticsRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.DescribeDomainAnalyticsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDomainAnalytics", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDomainAnalyticsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeDomainList(self, request):
         """获取域名列表
 
@@ -372,7 +442,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDomainList", params)
+            headers = request.headers
+            body = self.call("DescribeDomainList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDomainListResponse()
@@ -400,7 +471,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDomainLogList", params)
+            headers = request.headers
+            body = self.call("DescribeDomainLogList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDomainLogListResponse()
@@ -428,7 +500,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDomainPurview", params)
+            headers = request.headers
+            body = self.call("DescribeDomainPurview", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDomainPurviewResponse()
@@ -456,7 +529,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDomainShareInfo", params)
+            headers = request.headers
+            body = self.call("DescribeDomainShareInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDomainShareInfoResponse()
@@ -484,7 +558,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRecord", params)
+            headers = request.headers
+            body = self.call("DescribeRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRecordResponse()
@@ -512,7 +587,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRecordLineList", params)
+            headers = request.headers
+            body = self.call("DescribeRecordLineList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRecordLineListResponse()
@@ -540,7 +616,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRecordList", params)
+            headers = request.headers
+            body = self.call("DescribeRecordList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRecordListResponse()
@@ -568,7 +645,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRecordType", params)
+            headers = request.headers
+            body = self.call("DescribeRecordType", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRecordTypeResponse()
@@ -586,6 +664,35 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeSubdomainAnalytics(self, request):
+        """统计子域名的解析量，帮助您了解流量情况、时间段分布。支持查看近 3 个月内的统计情况。仅付费套餐域名可用。
+
+        :param request: Request instance for DescribeSubdomainAnalytics.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeSubdomainAnalyticsRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.DescribeSubdomainAnalyticsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSubdomainAnalytics", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeSubdomainAnalyticsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeUserDetail(self, request):
         """获取帐户信息
 
@@ -596,7 +703,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeUserDetail", params)
+            headers = request.headers
+            body = self.call("DescribeUserDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeUserDetailResponse()
@@ -624,7 +732,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDomainLock", params)
+            headers = request.headers
+            body = self.call("ModifyDomainLock", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDomainLockResponse()
@@ -652,7 +761,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDomainOwner", params)
+            headers = request.headers
+            body = self.call("ModifyDomainOwner", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDomainOwnerResponse()
@@ -680,7 +790,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDomainRemark", params)
+            headers = request.headers
+            body = self.call("ModifyDomainRemark", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDomainRemarkResponse()
@@ -708,7 +819,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDomainStatus", params)
+            headers = request.headers
+            body = self.call("ModifyDomainStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDomainStatusResponse()
@@ -736,7 +848,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDomainUnlock", params)
+            headers = request.headers
+            body = self.call("ModifyDomainUnlock", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDomainUnlockResponse()
@@ -764,7 +877,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDynamicDNS", params)
+            headers = request.headers
+            body = self.call("ModifyDynamicDNS", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDynamicDNSResponse()
@@ -792,7 +906,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyRecord", params)
+            headers = request.headers
+            body = self.call("ModifyRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyRecordResponse()
@@ -820,7 +935,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyRecordBatch", params)
+            headers = request.headers
+            body = self.call("ModifyRecordBatch", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyRecordBatchResponse()
@@ -848,7 +964,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyRecordRemark", params)
+            headers = request.headers
+            body = self.call("ModifyRecordRemark", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyRecordRemarkResponse()
@@ -876,7 +993,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyRecordStatus", params)
+            headers = request.headers
+            body = self.call("ModifyRecordStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyRecordStatusResponse()
@@ -904,7 +1022,8 @@ class DnspodClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySubdomainStatus", params)
+            headers = request.headers
+            body = self.call("ModifySubdomainStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySubdomainStatusResponse()
