@@ -47,6 +47,9 @@ INTERNALERROR_DATABASEERROR = 'InternalError.DatabaseError'
 # 迁移任务冲突。
 INTERNALERROR_DUPLICATEJOB = 'InternalError.DuplicateJob'
 
+# http请求访问出错。
+INTERNALERROR_INTERNALHTTPSERVERERROR = 'InternalError.InternalHttpServerError'
+
 # 内部组件访问错误。
 INTERNALERROR_INTERNALINNERCOMMONERROR = 'InternalError.InternalInnerCommonError'
 
