@@ -14,9 +14,15 @@
 # limitations under the License.
 
 
+# 操作失败。
+FAILEDOPERATION = 'FailedOperation'
+
 # 鉴权失败。
 FAILEDOPERATION_AUTHENTICATIONFAILED = 'FailedOperation.AuthenticationFailed'
 
+# 接口处理超时。
+FAILEDOPERATION_INNERLOGICTIMEOUT = 'FailedOperation.InnerLogicTimeOut'
+
 # 依赖服务错误。
 FAILEDOPERATION_METACOMPILERERROR = 'FailedOperation.MetaCompilerError'
 
